@@ -204,6 +204,10 @@ class BuiltinsTest(TestCase):
     async def test_list(self):
         self.assertEqual(await ait.list(ait.iter(slist)), slist)
 
+    @async_test
+    async def test_tuple(self):
+        self.assertEqual(await ait.tuple(ait.iter(slist)), tuple(slist))
+
     # aioitertools.set()
 
     @async_test
@@ -364,5 +368,5 @@ class BuiltinsTest(TestCase):
         long = [0, 1, 2, 3, 5]
 
         result = await ait.list(ait.zip(short, long))
-        expected = [["a", 0], ["b", 1], ["c", 2]]
+        expected = [("a", 0), ("b", 1), ("c", 2)]
         self.assertListEqual(expected, result)
